package com.liquidnet.service.zxlnft;

import com.liquidnet.common.third.zxlnft.biz.ZxlnftBiz;
import com.liquidnet.common.third.zxlnft.constant.ZxlnftEnum;
import com.liquidnet.common.third.zxlnft.dto.*;
import com.liquidnet.common.third.zxlnft.dto.wallet.CreateMnemonicReq;
import com.liquidnet.common.third.zxlnft.dto.wallet.CreateMnemonicResp;
import com.liquidnet.common.third.zxlnft.dto.wallet.DeriveKeyPairReq;
import com.liquidnet.common.third.zxlnft.dto.wallet.DeriveKeyPairResp;
import com.liquidnet.common.third.zxlnft.util.ZxlWalletSdkUtil;
import com.liquidnet.common.third.zxlnft.util.ZxlnftSdkUtil;
import lombok.extern.slf4j.Slf4j;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

/**
 * @author AnJiabin <anjiabin@zhengzai.tv>
 * @version V1.0
 * @Description: TODO
 * @class: TestZxlnftService
 * @Package com.liquidnet.service.zxlnft
 * @Copyright: LightNet @ Copyright (c) 2021
 * @date 2022/3/3 16:55
 */
@Slf4j
@RunWith(SpringJUnit4ClassRunner.class)
@SpringBootTest
public class TestZxlnftService {
    @Autowired
    private ZxlnftSdkUtil zxlnftSdkUtil;

    @Autowired
    private ZxlWalletSdkUtil zxlWalletSdkUtil;

    @Autowired
    private ZxlnftBiz zxlnftBiz;
    /**
     * 1、NFT平台在至信链的注册、审核
     */
    @Test
    public void platformRegister(){

//        1.1.2调用下发查询用户信息验证码接口
//        1.1.3调用查询用户信息接口
//        1.1.4调用下发用户信息查询验证码接口
//        1.1.5调用NFT平台自身地址绑定接口
//        1.1.6调用绑定状态批量查询接口

    }

    /**
     * 2、自然人用户通过NFT平台注册绑定
     */
    @Test
    public void personRegisterBind(){
        //生成助记词
        CreateMnemonicReq req = CreateMnemonicReq.getNew();
        CreateMnemonicResp createMnemonicResp = zxlWalletSdkUtil.createMnemonic(req);
        //生成公私钥
        DeriveKeyPairReq deriveKeyPairReq = DeriveKeyPairReq.getNew();
        deriveKeyPairReq.setMnemonic("economy cost balance weapon flight also nut biology very sun slight about");
//        deriveKeyPairReq.setMnemonic(createMnemonicResp.getMnemonic());
        deriveKeyPairReq.setIndex(1l);
        DeriveKeyPairResp deriveKeyPairResp = zxlWalletSdkUtil.deriveKeyPair(deriveKeyPairReq);



//        1.2.1调用自然人注册实名(使用NFT平台签名)接口
        Nft003RegisterPersonPlatformReqDto nft003ReqDto = Nft003RegisterPersonPlatformReqDto.getNew();
        nft003ReqDto.setPersonName("周焕");
//        reqDto.setEmail("");
        nft003ReqDto.setMobile("18548596019");
        nft003ReqDto.setIdCard("150422199805206019");

        nft003ReqDto.setCardType(Integer.valueOf(ZxlnftEnum.CardTypeEnum.ID_CARD.getCode()));
        ZxlnftResponseDto<Nft003RegisterPersonPlatformRespDto> nft003Resp = zxlnftSdkUtil.nft003RegisterPersonPlatform(nft003ReqDto);

//        1.2.2调用授信平台NFT地址绑定接口
        Nft014IdentityBindSubmitByTrustedReqDto nft004ReqDto = Nft014IdentityBindSubmitByTrustedReqDto.getNew();

        //周焕
        nft004ReqDto.setUserPubKey(deriveKeyPairResp.getPubKey());
        nft004ReqDto.setUserIdentification(nft003Resp.getData().getUserIdentification());

        String signature = zxlnftBiz.createSign(deriveKeyPairResp.getPriKey(),nft004ReqDto.getUserIdentification());
        nft004ReqDto.setUserSignData(signature);

        ZxlnftResponseDto<Nft014IdentityBindSubmitByTrustedRespDto> nft004Resp = zxlnftSdkUtil.nft014IdentityBindSubmitByTrusted(nft004ReqDto);

//        1.2.3调用绑定状态批量查询
        Nft016IdentityBindQueryReqDto nft016ReqDto = Nft016IdentityBindQueryReqDto.getNew();
        nft016ReqDto.setAddressList(nft004Resp.getData().getAddress());
        ZxlnftResponseDto<Nft016IdentityBindQueryRespDto> nft016Resp = zxlnftSdkUtil.nft016IdentityBindQuery(nft016ReqDto);
    }

    /**
     * 3、素材上传操作
     */
    @Test
    public void nftUpload(){
//        1.4.1调用图片内容检测接口
//        1.4.2调用生成素材上传临时密钥接口
//        1.4.3调用sdk接口-上传cos接口
//        1.4.4调用查询素材地址接口 -- 非必需
    }

    /**
     * 4、发行NFT
     */
    @Test
    public void nftPublish(){
//        3.1.1调用系列声明
//        3.1.2调用NFT发行接口
//        3.1.3调用NFT查询接口
//        3.1.4查询 NFT发行结果
    }

    /**
     * 5、购买NFT
     */
    @Test
    public void nftBuy(){
//        3.2.1调用积分申请接口
//        3.2.2调用购买NFT接口
//        3.2.3调用NFT查询接口
//        3.2.4查询NFT购买支付结果
    }

    /**
     * 6、查询NFT相关信息
     */
    @Test
    public void nftQuery(){

    }

}
